@@ -1,4 +1,4 @@
-/* $OpenBSD: cms_smime.c,v 1.24 2019/10/04 18:03:56 tb Exp $ */
+/* $OpenBSD: cms_smime.c,v 1.29 2025/05/10 05:54:38 tb Exp $ */
 /*
  * Written by Dr Stephen N Henson (steve@openssl.org) for the OpenSSL
  * project.
@@ -52,14 +52,21 @@
  * ====================================================================
  */
 
-#include "cryptlib.h"
-#include <openssl/asn1t.h>
-#include <openssl/x509.h>
-#include <openssl/x509v3.h>
-#include <openssl/err.h>
+#include <sys/types.h>
+
+#include <stddef.h>
+
+#include <openssl/asn1.h>
+#include <openssl/bio.h>
 #include <openssl/cms.h>
-#include "cms_lcl.h"
-#include "asn1/asn1_locl.h"
+#include <openssl/evp.h>
+#include <openssl/objects.h>
+#include <openssl/pkcs7.h>
+#include <openssl/x509.h>
+#include <openssl/x509_vfy.h>
+
+#include "cms_local.h"
+#include "err_local.h"
 
 static BIO *
 cms_get_text_bio(BIO *out, unsigned int flags)
@@ -170,6 +177,7 @@ CMS_data(CMS_ContentInfo *cms, BIO *out, unsigned int flags)
 
 	return r;
 }
+LCRYPTO_ALIAS(CMS_data);
 
 CMS_ContentInfo *
 CMS_data_create(BIO *in, unsigned int flags)
@@ -187,6 +195,7 @@ CMS_data_create(BIO *in, unsigned int flags)
 
 	return NULL;
 }
+LCRYPTO_ALIAS(CMS_data_create);
 
 int
 CMS_digest_verify(CMS_ContentInfo *cms, BIO *dcont, BIO *out, unsigned int flags)
@@ -212,6 +221,7 @@ CMS_digest_verify(CMS_ContentInfo *cms, BIO *dcont, BIO *out, unsigned int flags
 
 	return r;
 }
+LCRYPTO_ALIAS(CMS_digest_verify);
 
 CMS_ContentInfo *
 CMS_digest_create(BIO *in, const EVP_MD *md, unsigned int flags)
@@ -234,6 +244,7 @@ CMS_digest_create(BIO *in, const EVP_MD *md, unsigned int flags)
 
 	return NULL;
 }
+LCRYPTO_ALIAS(CMS_digest_create);
 
 int
 CMS_EncryptedData_decrypt(CMS_ContentInfo *cms, const unsigned char *key,
@@ -260,6 +271,7 @@ CMS_EncryptedData_decrypt(CMS_ContentInfo *cms, const unsigned char *key,
 
 	return r;
 }
+LCRYPTO_ALIAS(CMS_EncryptedData_decrypt);
 
 CMS_ContentInfo *
 CMS_EncryptedData_encrypt(BIO *in, const EVP_CIPHER *cipher,
@@ -288,6 +300,7 @@ CMS_EncryptedData_encrypt(BIO *in, const EVP_CIPHER *cipher,
 
 	return NULL;
 }
+LCRYPTO_ALIAS(CMS_EncryptedData_encrypt);
 
 static int
 cms_signerinfo_verify_cert(CMS_SignerInfo *si, X509_STORE *store,
@@ -485,6 +498,7 @@ CMS_verify(CMS_ContentInfo *cms, STACK_OF(X509) *certs, X509_STORE *store,
 
 	return ret;
 }
+LCRYPTO_ALIAS(CMS_verify);
 
 int
 CMS_verify_receipt(CMS_ContentInfo *rcms, CMS_ContentInfo *ocms,
@@ -499,6 +513,7 @@ CMS_verify_receipt(CMS_ContentInfo *rcms, CMS_ContentInfo *ocms,
 
 	return cms_Receipt_verify(rcms, ocms);
 }
+LCRYPTO_ALIAS(CMS_verify_receipt);
 
 CMS_ContentInfo *
 CMS_sign(X509 *signcert, EVP_PKEY *pkey, STACK_OF(X509) *certs, BIO *data,
@@ -542,6 +557,7 @@ CMS_sign(X509 *signcert, EVP_PKEY *pkey, STACK_OF(X509) *certs, BIO *data,
 
 	return NULL;
 }
+LCRYPTO_ALIAS(CMS_sign);
 
 CMS_ContentInfo *
 CMS_sign_receipt(CMS_SignerInfo *si, X509 *signcert, EVP_PKEY *pkey,
@@ -609,6 +625,7 @@ CMS_sign_receipt(CMS_SignerInfo *si, X509 *signcert, EVP_PKEY *pkey,
 
 	return NULL;
 }
+LCRYPTO_ALIAS(CMS_sign_receipt);
 
 CMS_ContentInfo *
 CMS_encrypt(STACK_OF(X509) *certs, BIO *data, const EVP_CIPHER *cipher,
@@ -645,6 +662,7 @@ CMS_encrypt(STACK_OF(X509) *certs, BIO *data, const EVP_CIPHER *cipher,
 
 	return NULL;
 }
+LCRYPTO_ALIAS(CMS_encrypt);
 
 static int
 cms_kari_set1_pkey(CMS_ContentInfo *cms, CMS_RecipientInfo *ri, EVP_PKEY *pk,
@@ -743,6 +761,7 @@ CMS_decrypt_set1_pkey(CMS_ContentInfo *cms, EVP_PKEY *pk, X509 *cert)
 
 	return 0;
 }
+LCRYPTO_ALIAS(CMS_decrypt_set1_pkey);
 
 int
 CMS_decrypt_set1_key(CMS_ContentInfo *cms, unsigned char *key, size_t keylen,
@@ -780,6 +799,7 @@ CMS_decrypt_set1_key(CMS_ContentInfo *cms, unsigned char *key, size_t keylen,
 
 	return 0;
 }
+LCRYPTO_ALIAS(CMS_decrypt_set1_key);
 
 int
 CMS_decrypt_set1_password(CMS_ContentInfo *cms, unsigned char *pass,
@@ -805,6 +825,7 @@ CMS_decrypt_set1_password(CMS_ContentInfo *cms, unsigned char *pass,
 
 	return 0;
 }
+LCRYPTO_ALIAS(CMS_decrypt_set1_password);
 
 int
 CMS_decrypt(CMS_ContentInfo *cms, EVP_PKEY *pk, X509 *cert, BIO *dcont,
@@ -839,6 +860,7 @@ CMS_decrypt(CMS_ContentInfo *cms, EVP_PKEY *pk, X509 *cert, BIO *dcont,
 
 	return r;
 }
+LCRYPTO_ALIAS(CMS_decrypt);
 
 int
 CMS_final(CMS_ContentInfo *cms, BIO *data, BIO *dcont, unsigned int flags)
@@ -867,55 +889,7 @@ CMS_final(CMS_ContentInfo *cms, BIO *data, BIO *dcont, unsigned int flags)
 
 	return ret;
 }
-
-#ifdef ZLIB
-
-int
-CMS_uncompress(CMS_ContentInfo *cms, BIO *dcont, BIO *out, unsigned int flags)
-{
-	BIO *cont;
-	int r;
-
-	if (OBJ_obj2nid(CMS_get0_type(cms)) != NID_id_smime_ct_compressedData) {
-		CMSerror(CMS_R_TYPE_NOT_COMPRESSED_DATA);
-		return 0;
-	}
-
-	if (!dcont && !check_content(cms))
-		return 0;
-
-	cont = CMS_dataInit(cms, dcont);
-	if (!cont)
-		return 0;
-	r = cms_copy_content(out, cont, flags);
-	do_free_upto(cont, dcont);
-
-	return r;
-}
-
-CMS_ContentInfo *
-CMS_compress(BIO *in, int comp_nid, unsigned int flags)
-{
-	CMS_ContentInfo *cms;
-
-	if (comp_nid <= 0)
-		comp_nid = NID_zlib_compression;
-	cms = cms_CompressedData_create(comp_nid);
-	if (!cms)
-		return NULL;
-
-	if (!(flags & CMS_DETACHED))
-		CMS_set_detached(cms, 0);
-
-	if ((flags & CMS_STREAM) || CMS_final(cms, in, NULL, flags))
-		return cms;
-
-	CMS_ContentInfo_free(cms);
-
-	return NULL;
-}
-
-#else
+LCRYPTO_ALIAS(CMS_final);
 
 int
 CMS_uncompress(CMS_ContentInfo *cms, BIO *dcont, BIO *out, unsigned int flags)
@@ -923,6 +897,7 @@ CMS_uncompress(CMS_ContentInfo *cms, BIO *dcont, BIO *out, unsigned int flags)
 	CMSerror(CMS_R_UNSUPPORTED_COMPRESSION_ALGORITHM);
 	return 0;
 }
+LCRYPTO_ALIAS(CMS_uncompress);
 
 CMS_ContentInfo *
 CMS_compress(BIO *in, int comp_nid, unsigned int flags)
@@ -930,5 +905,4 @@ CMS_compress(BIO *in, int comp_nid, unsigned int flags)
 	CMSerror(CMS_R_UNSUPPORTED_COMPRESSION_ALGORITHM);
 	return NULL;
 }
-
-#endif
+LCRYPTO_ALIAS(CMS_compress);
