@@ -3,7 +3,10 @@
 
 #include <sys/param.h>
 
-#if defined(__FreeBSD__)
+#if defined(_AIX)
+#include "arc4random_aix.h"
+
+#elif defined(__FreeBSD__)
 #include "arc4random_freebsd.h"
 
 #elif defined(__hpux)
@@ -12,6 +15,9 @@
 #elif defined(__linux__)
 #include "arc4random_linux.h"
 
+#elif defined(__midipix__)
+#include "arc4random_linux.h"
+
 #elif defined(__NetBSD__)
 #include "arc4random_netbsd.h"
 
@@ -24,6 +30,9 @@
 #elif defined(_WIN32)
 #include "arc4random_win.h"
 
+#elif defined(__EMSCRIPTEN__)
+#include "arc4random_linux.h"
+
 #else
 #error "No arc4random hooks defined for this platform."
 
