@@ -1,4 +1,4 @@
-/* $OpenBSD: dsa_asn1.c,v 1.30 2023/03/25 09:09:28 tb Exp $ */
+/* $OpenBSD: dsa_asn1.c,v 1.34 2025/05/10 05:54:38 tb Exp $ */
 /* Written by Dr Stephen N Henson (steve@openssl.org) for the OpenSSL
  * project 2000.
  */
@@ -63,9 +63,9 @@
 #include <openssl/asn1t.h>
 #include <openssl/bn.h>
 #include <openssl/dsa.h>
-#include <openssl/err.h>
 
 #include "dsa_local.h"
+#include "err_local.h"
 
 /* Override the default new methods */
 static int
@@ -109,7 +109,7 @@ static const ASN1_TEMPLATE DSA_SIG_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM DSA_SIG_it = {
+static const ASN1_ITEM DSA_SIG_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = DSA_SIG_seq_tt,
@@ -126,12 +126,14 @@ d2i_DSA_SIG(DSA_SIG **a, const unsigned char **in, long len)
 	return (DSA_SIG *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &DSA_SIG_it);
 }
+LCRYPTO_ALIAS(d2i_DSA_SIG);
 
 int
 i2d_DSA_SIG(const DSA_SIG *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &DSA_SIG_it);
 }
+LCRYPTO_ALIAS(i2d_DSA_SIG);
 
 void
 DSA_SIG_get0(const DSA_SIG *sig, const BIGNUM **pr, const BIGNUM **ps)
@@ -141,6 +143,7 @@ DSA_SIG_get0(const DSA_SIG *sig, const BIGNUM **pr, const BIGNUM **ps)
 	if (ps != NULL)
 		*ps = sig->s;
 }
+LCRYPTO_ALIAS(DSA_SIG_get0);
 
 int
 DSA_SIG_set0(DSA_SIG *sig, BIGNUM *r, BIGNUM *s)
@@ -155,6 +158,7 @@ DSA_SIG_set0(DSA_SIG *sig, BIGNUM *r, BIGNUM *s)
 
 	return 1;
 }
+LCRYPTO_ALIAS(DSA_SIG_set0);
 
 /* Override the default free and new methods */
 static int
@@ -235,6 +239,7 @@ const ASN1_ITEM DSAPrivateKey_it = {
 	.size = sizeof(DSA),
 	.sname = "DSA",
 };
+LCRYPTO_ALIAS(DSAPrivateKey_it);
 
 
 DSA *
@@ -243,12 +248,14 @@ d2i_DSAPrivateKey(DSA **a, const unsigned char **in, long len)
 	return (DSA *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &DSAPrivateKey_it);
 }
+LCRYPTO_ALIAS(d2i_DSAPrivateKey);
 
 int
 i2d_DSAPrivateKey(const DSA *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &DSAPrivateKey_it);
 }
+LCRYPTO_ALIAS(i2d_DSAPrivateKey);
 
 static const ASN1_AUX DSAparams_aux = {
 	.app_data = NULL,
@@ -291,6 +298,7 @@ const ASN1_ITEM DSAparams_it = {
 	.size = sizeof(DSA),
 	.sname = "DSA",
 };
+LCRYPTO_ALIAS(DSAparams_it);
 
 
 DSA *
@@ -299,36 +307,42 @@ d2i_DSAparams(DSA **a, const unsigned char **in, long len)
 	return (DSA *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &DSAparams_it);
 }
+LCRYPTO_ALIAS(d2i_DSAparams);
 
 int
 i2d_DSAparams(const DSA *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &DSAparams_it);
 }
+LCRYPTO_ALIAS(i2d_DSAparams);
 
 DSA *
 d2i_DSAparams_bio(BIO *bp, DSA **a)
 {
 	return ASN1_item_d2i_bio(&DSAparams_it, bp, a);
 }
+LCRYPTO_ALIAS(d2i_DSAparams_bio);
 
 int
 i2d_DSAparams_bio(BIO *bp, DSA *a)
 {
 	return ASN1_item_i2d_bio(&DSAparams_it, bp, a);
 }
+LCRYPTO_ALIAS(i2d_DSAparams_bio);
 
 DSA *
 d2i_DSAparams_fp(FILE *fp, DSA **a)
 {
 	return ASN1_item_d2i_fp(&DSAparams_it, fp, a);
 }
+LCRYPTO_ALIAS(d2i_DSAparams_fp);
 
 int
 i2d_DSAparams_fp(FILE *fp, DSA *a)
 {
 	return ASN1_item_i2d_fp(&DSAparams_it, fp, a);
 }
+LCRYPTO_ALIAS(i2d_DSAparams_fp);
 
 static const ASN1_AUX DSAPublicKey_aux = {
 	.app_data = NULL,
@@ -378,6 +392,7 @@ const ASN1_ITEM DSAPublicKey_it = {
 	.size = sizeof(DSA),
 	.sname = "DSA",
 };
+LCRYPTO_ALIAS(DSAPublicKey_it);
 
 DSA *
 d2i_DSAPublicKey(DSA **a, const unsigned char **in, long len)
@@ -385,18 +400,21 @@ d2i_DSAPublicKey(DSA **a, const unsigned char **in, long len)
 	return (DSA *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &DSAPublicKey_it);
 }
+LCRYPTO_ALIAS(d2i_DSAPublicKey);
 
 int
 i2d_DSAPublicKey(const DSA *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &DSAPublicKey_it);
 }
+LCRYPTO_ALIAS(i2d_DSAPublicKey);
 
 DSA *
 DSAparams_dup(DSA *dsa)
 {
 	return ASN1_item_dup(&DSAparams_it, dsa);
 }
+LCRYPTO_ALIAS(DSAparams_dup);
 
 int
 DSA_sign(int type, const unsigned char *dgst, int dlen, unsigned char *sig,
@@ -422,6 +440,7 @@ DSA_sign(int type, const unsigned char *dgst, int dlen, unsigned char *sig,
 
 	return ret;
 }
+LCRYPTO_ALIAS(DSA_sign);
 
 /*
  * data has already been hashed (probably with SHA or SHA-1).
@@ -457,3 +476,4 @@ DSA_verify(int type, const unsigned char *dgst, int dgst_len,
 
 	return ret;
 }
+LCRYPTO_ALIAS(DSA_verify);
