@@ -1,4 +1,4 @@
-/* $OpenBSD: dsa_prn.c,v 1.6 2017/01/29 17:49:22 beck Exp $ */
+/* $OpenBSD: dsa_prn.c,v 1.11 2025/05/10 05:54:38 tb Exp $ */
 /* Written by Dr Stephen N Henson (steve@openssl.org) for the OpenSSL
  * project 2006.
  */
@@ -10,7 +10,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in
@@ -59,9 +59,10 @@
 #include <stdio.h>
 
 #include <openssl/dsa.h>
-#include <openssl/err.h>
 #include <openssl/evp.h>
 
+#include "err_local.h"
+
 int
 DSA_print_fp(FILE *fp, const DSA *x, int off)
 {
@@ -77,6 +78,7 @@ DSA_print_fp(FILE *fp, const DSA *x, int off)
 	BIO_free(b);
 	return ret;
 }
+LCRYPTO_ALIAS(DSA_print_fp);
 
 int
 DSAparams_print_fp(FILE *fp, const DSA *x)
@@ -93,31 +95,42 @@ DSAparams_print_fp(FILE *fp, const DSA *x)
 	BIO_free(b);
 	return ret;
 }
+LCRYPTO_ALIAS(DSAparams_print_fp);
 
 int
 DSA_print(BIO *bp, const DSA *x, int off)
 {
 	EVP_PKEY *pk;
-	int ret;
+	int ret = 0;
+
+	if ((pk = EVP_PKEY_new()) == NULL)
+		goto err;
+
+	if (!EVP_PKEY_set1_DSA(pk, (DSA *)x))
+		goto err;
 
-	pk = EVP_PKEY_new();
-	if (!pk || !EVP_PKEY_set1_DSA(pk, (DSA *)x))
-		return 0;
 	ret = EVP_PKEY_print_private(bp, pk, off, NULL);
+ err:
 	EVP_PKEY_free(pk);
 	return ret;
 }
+LCRYPTO_ALIAS(DSA_print);
 
 int
 DSAparams_print(BIO *bp, const DSA *x)
 {
 	EVP_PKEY *pk;
-	int ret;
+	int ret = 0;
+
+	if ((pk = EVP_PKEY_new()) == NULL)
+		goto err;
+
+	if (!EVP_PKEY_set1_DSA(pk, (DSA *)x))
+		goto err;
 
-	pk = EVP_PKEY_new();
-	if (!pk || !EVP_PKEY_set1_DSA(pk, (DSA *)x))
-		return 0;
 	ret = EVP_PKEY_print_params(bp, pk, 4, NULL);
+ err:
 	EVP_PKEY_free(pk);
 	return ret;
 }
+LCRYPTO_ALIAS(DSAparams_print);
