@@ -1,4 +1,4 @@
-/* $OpenBSD: m_sha1.c,v 1.25 2023/07/07 19:37:53 beck Exp $ */
+/* $OpenBSD: m_sha1.c,v 1.26 2024/04/09 13:52:41 beck Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -110,6 +110,7 @@ EVP_sha1(void)
 {
 	return &sha1_md;
 }
+LCRYPTO_ALIAS(EVP_sha1);
 #endif
 
 #ifndef OPENSSL_NO_SHA256
@@ -155,6 +156,7 @@ EVP_sha224(void)
 {
 	return &sha224_md;
 }
+LCRYPTO_ALIAS(EVP_sha224);
 
 static int
 sha256_init(EVP_MD_CTX *ctx)
@@ -193,6 +195,7 @@ EVP_sha256(void)
 {
 	return &sha256_md;
 }
+LCRYPTO_ALIAS(EVP_sha256);
 #endif	/* ifndef OPENSSL_NO_SHA256 */
 
 #ifndef OPENSSL_NO_SHA512
@@ -234,6 +237,7 @@ EVP_sha384(void)
 {
 	return &sha384_md;
 }
+LCRYPTO_ALIAS(EVP_sha384);
 
 static int
 sha512_init(EVP_MD_CTX *ctx)
@@ -272,6 +276,7 @@ EVP_sha512(void)
 {
 	return &sha512_md;
 }
+LCRYPTO_ALIAS(EVP_sha512);
 
 static int
 sha512_224_init(EVP_MD_CTX *ctx)
@@ -310,6 +315,7 @@ EVP_sha512_224(void)
 {
 	return &sha512_224_md;
 }
+LCRYPTO_ALIAS(EVP_sha512_224);
 
 static int
 sha512_256_init(EVP_MD_CTX *ctx)
@@ -348,4 +354,5 @@ EVP_sha512_256(void)
 {
 	return &sha512_256_md;
 }
+LCRYPTO_ALIAS(EVP_sha512_256);
 #endif	/* ifndef OPENSSL_NO_SHA512 */
