@@ -1,4 +1,4 @@
-/* $OpenBSD: ts_asn1.c,v 1.10 2016/11/04 18:35:30 jsing Exp $ */
+/* $OpenBSD: ts_asn1.c,v 1.16 2025/05/10 05:54:39 tb Exp $ */
 /* Written by Nils Larsch for the OpenSSL project 2004.
  */
 /* ====================================================================
@@ -58,9 +58,11 @@
 #include <openssl/opensslconf.h>
 
 #include <openssl/ts.h>
-#include <openssl/err.h>
 #include <openssl/asn1t.h>
 
+#include "err_local.h"
+#include "ts_local.h"
+
 static const ASN1_TEMPLATE TS_MSG_IMPRINT_seq_tt[] = {
 	{
 		.flags = 0,
@@ -78,7 +80,7 @@ static const ASN1_TEMPLATE TS_MSG_IMPRINT_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM TS_MSG_IMPRINT_it = {
+static const ASN1_ITEM TS_MSG_IMPRINT_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = TS_MSG_IMPRINT_seq_tt,
@@ -95,30 +97,35 @@ d2i_TS_MSG_IMPRINT(TS_MSG_IMPRINT **a, const unsigned char **in, long len)
 	return (TS_MSG_IMPRINT *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &TS_MSG_IMPRINT_it);
 }
+LCRYPTO_ALIAS(d2i_TS_MSG_IMPRINT);
 
 int
 i2d_TS_MSG_IMPRINT(const TS_MSG_IMPRINT *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &TS_MSG_IMPRINT_it);
 }
+LCRYPTO_ALIAS(i2d_TS_MSG_IMPRINT);
 
 TS_MSG_IMPRINT *
 TS_MSG_IMPRINT_new(void)
 {
 	return (TS_MSG_IMPRINT *)ASN1_item_new(&TS_MSG_IMPRINT_it);
 }
+LCRYPTO_ALIAS(TS_MSG_IMPRINT_new);
 
 void
 TS_MSG_IMPRINT_free(TS_MSG_IMPRINT *a)
 {
 	ASN1_item_free((ASN1_VALUE *)a, &TS_MSG_IMPRINT_it);
 }
+LCRYPTO_ALIAS(TS_MSG_IMPRINT_free);
 
 TS_MSG_IMPRINT *
 TS_MSG_IMPRINT_dup(TS_MSG_IMPRINT *x)
 {
 	return ASN1_item_dup(&TS_MSG_IMPRINT_it, x);
 }
+LCRYPTO_ALIAS(TS_MSG_IMPRINT_dup);
 
 #ifndef OPENSSL_NO_BIO
 TS_MSG_IMPRINT *
@@ -126,12 +133,14 @@ d2i_TS_MSG_IMPRINT_bio(BIO *bp, TS_MSG_IMPRINT **a)
 {
 	return ASN1_item_d2i_bio(&TS_MSG_IMPRINT_it, bp, a);
 }
+LCRYPTO_ALIAS(d2i_TS_MSG_IMPRINT_bio);
 
 int
 i2d_TS_MSG_IMPRINT_bio(BIO *bp, TS_MSG_IMPRINT *a)
 {
 	return ASN1_item_i2d_bio(&TS_MSG_IMPRINT_it, bp, a);
 }
+LCRYPTO_ALIAS(i2d_TS_MSG_IMPRINT_bio);
 #endif
 
 TS_MSG_IMPRINT *
@@ -139,12 +148,14 @@ d2i_TS_MSG_IMPRINT_fp(FILE *fp, TS_MSG_IMPRINT **a)
 {
 	return ASN1_item_d2i_fp(&TS_MSG_IMPRINT_it, fp, a);
 }
+LCRYPTO_ALIAS(d2i_TS_MSG_IMPRINT_fp);
 
 int
 i2d_TS_MSG_IMPRINT_fp(FILE *fp, TS_MSG_IMPRINT *a)
 {
 	return ASN1_item_i2d_fp(&TS_MSG_IMPRINT_it, fp, a);
 }
+LCRYPTO_ALIAS(i2d_TS_MSG_IMPRINT_fp);
 
 static const ASN1_TEMPLATE TS_REQ_seq_tt[] = {
 	{
@@ -191,7 +202,7 @@ static const ASN1_TEMPLATE TS_REQ_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM TS_REQ_it = {
+static const ASN1_ITEM TS_REQ_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = TS_REQ_seq_tt,
@@ -208,30 +219,35 @@ d2i_TS_REQ(TS_REQ **a, const unsigned char **in, long len)
 	return (TS_REQ *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &TS_REQ_it);
 }
+LCRYPTO_ALIAS(d2i_TS_REQ);
 
 int
 i2d_TS_REQ(const TS_REQ *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &TS_REQ_it);
 }
+LCRYPTO_ALIAS(i2d_TS_REQ);
 
 TS_REQ *
 TS_REQ_new(void)
 {
 	return (TS_REQ *)ASN1_item_new(&TS_REQ_it);
 }
+LCRYPTO_ALIAS(TS_REQ_new);
 
 void
 TS_REQ_free(TS_REQ *a)
 {
 	ASN1_item_free((ASN1_VALUE *)a, &TS_REQ_it);
 }
+LCRYPTO_ALIAS(TS_REQ_free);
 
 TS_REQ *
 TS_REQ_dup(TS_REQ *x)
 {
 	return ASN1_item_dup(&TS_REQ_it, x);
 }
+LCRYPTO_ALIAS(TS_REQ_dup);
 
 #ifndef OPENSSL_NO_BIO
 TS_REQ *
@@ -239,12 +255,14 @@ d2i_TS_REQ_bio(BIO *bp, TS_REQ **a)
 {
 	return ASN1_item_d2i_bio(&TS_REQ_it, bp, a);
 }
+LCRYPTO_ALIAS(d2i_TS_REQ_bio);
 
 int
 i2d_TS_REQ_bio(BIO *bp, TS_REQ *a)
 {
 	return ASN1_item_i2d_bio(&TS_REQ_it, bp, a);
 }
+LCRYPTO_ALIAS(i2d_TS_REQ_bio);
 #endif
 
 TS_REQ *
@@ -252,12 +270,14 @@ d2i_TS_REQ_fp(FILE *fp, TS_REQ **a)
 {
 	return ASN1_item_d2i_fp(&TS_REQ_it, fp, a);
 }
+LCRYPTO_ALIAS(d2i_TS_REQ_fp);
 
 int
 i2d_TS_REQ_fp(FILE *fp, TS_REQ *a)
 {
 	return ASN1_item_i2d_fp(&TS_REQ_it, fp, a);
 }
+LCRYPTO_ALIAS(i2d_TS_REQ_fp);
 
 static const ASN1_TEMPLATE TS_ACCURACY_seq_tt[] = {
 	{
@@ -283,7 +303,7 @@ static const ASN1_TEMPLATE TS_ACCURACY_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM TS_ACCURACY_it = {
+static const ASN1_ITEM TS_ACCURACY_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = TS_ACCURACY_seq_tt,
@@ -300,30 +320,35 @@ d2i_TS_ACCURACY(TS_ACCURACY **a, const unsigned char **in, long len)
 	return (TS_ACCURACY *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &TS_ACCURACY_it);
 }
+LCRYPTO_ALIAS(d2i_TS_ACCURACY);
 
 int
 i2d_TS_ACCURACY(const TS_ACCURACY *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &TS_ACCURACY_it);
 }
+LCRYPTO_ALIAS(i2d_TS_ACCURACY);
 
 TS_ACCURACY *
 TS_ACCURACY_new(void)
 {
 	return (TS_ACCURACY *)ASN1_item_new(&TS_ACCURACY_it);
 }
+LCRYPTO_ALIAS(TS_ACCURACY_new);
 
 void
 TS_ACCURACY_free(TS_ACCURACY *a)
 {
 	ASN1_item_free((ASN1_VALUE *)a, &TS_ACCURACY_it);
 }
+LCRYPTO_ALIAS(TS_ACCURACY_free);
 
 TS_ACCURACY *
 TS_ACCURACY_dup(TS_ACCURACY *x)
 {
 	return ASN1_item_dup(&TS_ACCURACY_it, x);
 }
+LCRYPTO_ALIAS(TS_ACCURACY_dup);
 
 static const ASN1_TEMPLATE TS_TST_INFO_seq_tt[] = {
 	{
@@ -398,7 +423,7 @@ static const ASN1_TEMPLATE TS_TST_INFO_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM TS_TST_INFO_it = {
+static const ASN1_ITEM TS_TST_INFO_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = TS_TST_INFO_seq_tt,
@@ -415,30 +440,35 @@ d2i_TS_TST_INFO(TS_TST_INFO **a, const unsigned char **in, long len)
 	return (TS_TST_INFO *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &TS_TST_INFO_it);
 }
+LCRYPTO_ALIAS(d2i_TS_TST_INFO);
 
 int
 i2d_TS_TST_INFO(const TS_TST_INFO *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &TS_TST_INFO_it);
 }
+LCRYPTO_ALIAS(i2d_TS_TST_INFO);
 
 TS_TST_INFO *
 TS_TST_INFO_new(void)
 {
 	return (TS_TST_INFO *)ASN1_item_new(&TS_TST_INFO_it);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_new);
 
 void
 TS_TST_INFO_free(TS_TST_INFO *a)
 {
 	ASN1_item_free((ASN1_VALUE *)a, &TS_TST_INFO_it);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_free);
 
 TS_TST_INFO *
 TS_TST_INFO_dup(TS_TST_INFO *x)
 {
 	return ASN1_item_dup(&TS_TST_INFO_it, x);
 }
+LCRYPTO_ALIAS(TS_TST_INFO_dup);
 
 #ifndef OPENSSL_NO_BIO
 TS_TST_INFO *
@@ -446,12 +476,14 @@ d2i_TS_TST_INFO_bio(BIO *bp, TS_TST_INFO **a)
 {
 	return ASN1_item_d2i_bio(&TS_TST_INFO_it, bp, a);
 }
+LCRYPTO_ALIAS(d2i_TS_TST_INFO_bio);
 
 int
 i2d_TS_TST_INFO_bio(BIO *bp, TS_TST_INFO *a)
 {
 	return ASN1_item_i2d_bio(&TS_TST_INFO_it, bp, a);
 }
+LCRYPTO_ALIAS(i2d_TS_TST_INFO_bio);
 #endif
 
 TS_TST_INFO *
@@ -459,12 +491,14 @@ d2i_TS_TST_INFO_fp(FILE *fp, TS_TST_INFO **a)
 {
 	return ASN1_item_d2i_fp(&TS_TST_INFO_it, fp, a);
 }
+LCRYPTO_ALIAS(d2i_TS_TST_INFO_fp);
 
 int
 i2d_TS_TST_INFO_fp(FILE *fp, TS_TST_INFO *a)
 {
 	return ASN1_item_i2d_fp(&TS_TST_INFO_it, fp, a);
 }
+LCRYPTO_ALIAS(i2d_TS_TST_INFO_fp);
 
 static const ASN1_TEMPLATE TS_STATUS_INFO_seq_tt[] = {
 	{
@@ -490,7 +524,7 @@ static const ASN1_TEMPLATE TS_STATUS_INFO_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM TS_STATUS_INFO_it = {
+static const ASN1_ITEM TS_STATUS_INFO_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = TS_STATUS_INFO_seq_tt,
@@ -507,30 +541,35 @@ d2i_TS_STATUS_INFO(TS_STATUS_INFO **a, const unsigned char **in, long len)
 	return (TS_STATUS_INFO *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &TS_STATUS_INFO_it);
 }
+LCRYPTO_ALIAS(d2i_TS_STATUS_INFO);
 
 int
 i2d_TS_STATUS_INFO(const TS_STATUS_INFO *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &TS_STATUS_INFO_it);
 }
+LCRYPTO_ALIAS(i2d_TS_STATUS_INFO);
 
 TS_STATUS_INFO *
 TS_STATUS_INFO_new(void)
 {
 	return (TS_STATUS_INFO *)ASN1_item_new(&TS_STATUS_INFO_it);
 }
+LCRYPTO_ALIAS(TS_STATUS_INFO_new);
 
 void
 TS_STATUS_INFO_free(TS_STATUS_INFO *a)
 {
 	ASN1_item_free((ASN1_VALUE *)a, &TS_STATUS_INFO_it);
 }
+LCRYPTO_ALIAS(TS_STATUS_INFO_free);
 
 TS_STATUS_INFO *
 TS_STATUS_INFO_dup(TS_STATUS_INFO *x)
 {
 	return ASN1_item_dup(&TS_STATUS_INFO_it, x);
 }
+LCRYPTO_ALIAS(TS_STATUS_INFO_dup);
 
 static int
 ts_resp_set_tst_info(TS_RESP *a)
@@ -601,7 +640,7 @@ static const ASN1_TEMPLATE TS_RESP_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM TS_RESP_it = {
+static const ASN1_ITEM TS_RESP_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = TS_RESP_seq_tt,
@@ -618,30 +657,35 @@ d2i_TS_RESP(TS_RESP **a, const unsigned char **in, long len)
 	return (TS_RESP *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &TS_RESP_it);
 }
+LCRYPTO_ALIAS(d2i_TS_RESP);
 
 int
 i2d_TS_RESP(const TS_RESP *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &TS_RESP_it);
 }
+LCRYPTO_ALIAS(i2d_TS_RESP);
 
 TS_RESP *
 TS_RESP_new(void)
 {
 	return (TS_RESP *)ASN1_item_new(&TS_RESP_it);
 }
+LCRYPTO_ALIAS(TS_RESP_new);
 
 void
 TS_RESP_free(TS_RESP *a)
 {
 	ASN1_item_free((ASN1_VALUE *)a, &TS_RESP_it);
 }
+LCRYPTO_ALIAS(TS_RESP_free);
 
 TS_RESP *
 TS_RESP_dup(TS_RESP *x)
 {
 	return ASN1_item_dup(&TS_RESP_it, x);
 }
+LCRYPTO_ALIAS(TS_RESP_dup);
 
 #ifndef OPENSSL_NO_BIO
 TS_RESP *
@@ -649,12 +693,14 @@ d2i_TS_RESP_bio(BIO *bp, TS_RESP **a)
 {
 	return ASN1_item_d2i_bio(&TS_RESP_it, bp, a);
 }
+LCRYPTO_ALIAS(d2i_TS_RESP_bio);
 
 int
 i2d_TS_RESP_bio(BIO *bp, TS_RESP *a)
 {
 	return ASN1_item_i2d_bio(&TS_RESP_it, bp, a);
 }
+LCRYPTO_ALIAS(i2d_TS_RESP_bio);
 #endif
 
 TS_RESP *
@@ -662,12 +708,14 @@ d2i_TS_RESP_fp(FILE *fp, TS_RESP **a)
 {
 	return ASN1_item_d2i_fp(&TS_RESP_it, fp, a);
 }
+LCRYPTO_ALIAS(d2i_TS_RESP_fp);
 
 int
 i2d_TS_RESP_fp(FILE *fp, TS_RESP *a)
 {
 	return ASN1_item_i2d_fp(&TS_RESP_it, fp, a);
 }
+LCRYPTO_ALIAS(i2d_TS_RESP_fp);
 
 static const ASN1_TEMPLATE ESS_ISSUER_SERIAL_seq_tt[] = {
 	{
@@ -686,7 +734,7 @@ static const ASN1_TEMPLATE ESS_ISSUER_SERIAL_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM ESS_ISSUER_SERIAL_it = {
+static const ASN1_ITEM ESS_ISSUER_SERIAL_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = ESS_ISSUER_SERIAL_seq_tt,
@@ -703,30 +751,35 @@ d2i_ESS_ISSUER_SERIAL(ESS_ISSUER_SERIAL **a, const unsigned char **in, long len)
 	return (ESS_ISSUER_SERIAL *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &ESS_ISSUER_SERIAL_it);
 }
+LCRYPTO_ALIAS(d2i_ESS_ISSUER_SERIAL);
 
 int
 i2d_ESS_ISSUER_SERIAL(const ESS_ISSUER_SERIAL *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &ESS_ISSUER_SERIAL_it);
 }
+LCRYPTO_ALIAS(i2d_ESS_ISSUER_SERIAL);
 
 ESS_ISSUER_SERIAL *
 ESS_ISSUER_SERIAL_new(void)
 {
 	return (ESS_ISSUER_SERIAL *)ASN1_item_new(&ESS_ISSUER_SERIAL_it);
 }
+LCRYPTO_ALIAS(ESS_ISSUER_SERIAL_new);
 
 void
 ESS_ISSUER_SERIAL_free(ESS_ISSUER_SERIAL *a)
 {
 	ASN1_item_free((ASN1_VALUE *)a, &ESS_ISSUER_SERIAL_it);
 }
+LCRYPTO_ALIAS(ESS_ISSUER_SERIAL_free);
 
 ESS_ISSUER_SERIAL *
 ESS_ISSUER_SERIAL_dup(ESS_ISSUER_SERIAL *x)
 {
 	return ASN1_item_dup(&ESS_ISSUER_SERIAL_it, x);
 }
+LCRYPTO_ALIAS(ESS_ISSUER_SERIAL_dup);
 
 static const ASN1_TEMPLATE ESS_CERT_ID_seq_tt[] = {
 	{
@@ -745,7 +798,7 @@ static const ASN1_TEMPLATE ESS_CERT_ID_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM ESS_CERT_ID_it = {
+static const ASN1_ITEM ESS_CERT_ID_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = ESS_CERT_ID_seq_tt,
@@ -762,30 +815,35 @@ d2i_ESS_CERT_ID(ESS_CERT_ID **a, const unsigned char **in, long len)
 	return (ESS_CERT_ID *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &ESS_CERT_ID_it);
 }
+LCRYPTO_ALIAS(d2i_ESS_CERT_ID);
 
 int
 i2d_ESS_CERT_ID(const ESS_CERT_ID *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &ESS_CERT_ID_it);
 }
+LCRYPTO_ALIAS(i2d_ESS_CERT_ID);
 
 ESS_CERT_ID *
 ESS_CERT_ID_new(void)
 {
 	return (ESS_CERT_ID *)ASN1_item_new(&ESS_CERT_ID_it);
 }
+LCRYPTO_ALIAS(ESS_CERT_ID_new);
 
 void
 ESS_CERT_ID_free(ESS_CERT_ID *a)
 {
 	ASN1_item_free((ASN1_VALUE *)a, &ESS_CERT_ID_it);
 }
+LCRYPTO_ALIAS(ESS_CERT_ID_free);
 
 ESS_CERT_ID *
 ESS_CERT_ID_dup(ESS_CERT_ID *x)
 {
 	return ASN1_item_dup(&ESS_CERT_ID_it, x);
 }
+LCRYPTO_ALIAS(ESS_CERT_ID_dup);
 
 static const ASN1_TEMPLATE ESS_SIGNING_CERT_seq_tt[] = {
 	{
@@ -804,7 +862,7 @@ static const ASN1_TEMPLATE ESS_SIGNING_CERT_seq_tt[] = {
 	},
 };
 
-const ASN1_ITEM ESS_SIGNING_CERT_it = {
+static const ASN1_ITEM ESS_SIGNING_CERT_it = {
 	.itype = ASN1_ITYPE_SEQUENCE,
 	.utype = V_ASN1_SEQUENCE,
 	.templates = ESS_SIGNING_CERT_seq_tt,
@@ -821,30 +879,158 @@ d2i_ESS_SIGNING_CERT(ESS_SIGNING_CERT **a, const unsigned char **in, long len)
 	return (ESS_SIGNING_CERT *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
 	    &ESS_SIGNING_CERT_it);
 }
+LCRYPTO_ALIAS(d2i_ESS_SIGNING_CERT);
 
 int
 i2d_ESS_SIGNING_CERT(const ESS_SIGNING_CERT *a, unsigned char **out)
 {
 	return ASN1_item_i2d((ASN1_VALUE *)a, out, &ESS_SIGNING_CERT_it);
 }
+LCRYPTO_ALIAS(i2d_ESS_SIGNING_CERT);
 
 ESS_SIGNING_CERT *
 ESS_SIGNING_CERT_new(void)
 {
 	return (ESS_SIGNING_CERT *)ASN1_item_new(&ESS_SIGNING_CERT_it);
 }
+LCRYPTO_ALIAS(ESS_SIGNING_CERT_new);
 
 void
 ESS_SIGNING_CERT_free(ESS_SIGNING_CERT *a)
 {
 	ASN1_item_free((ASN1_VALUE *)a, &ESS_SIGNING_CERT_it);
 }
+LCRYPTO_ALIAS(ESS_SIGNING_CERT_free);
 
 ESS_SIGNING_CERT *
 ESS_SIGNING_CERT_dup(ESS_SIGNING_CERT *x)
 {
 	return ASN1_item_dup(&ESS_SIGNING_CERT_it, x);
 }
+LCRYPTO_ALIAS(ESS_SIGNING_CERT_dup);
+
+static const ASN1_TEMPLATE ESS_CERT_ID_V2_seq_tt[] = {
+	{
+		.flags = ASN1_TFLG_OPTIONAL,
+		.tag = 0,
+		.offset = offsetof(ESS_CERT_ID_V2, hash_alg),
+		.field_name = "hash_alg",
+		.item = &X509_ALGOR_it,
+	},
+	{
+		.flags = 0,
+		.tag = 0,
+		.offset = offsetof(ESS_CERT_ID_V2, hash),
+		.field_name = "hash",
+		.item = &ASN1_OCTET_STRING_it,
+	},
+	{
+		.flags = ASN1_TFLG_OPTIONAL,
+		.tag = 0,
+		.offset = offsetof(ESS_CERT_ID_V2, issuer_serial),
+		.field_name = "issuer_serial",
+		.item = &ESS_ISSUER_SERIAL_it,
+	},
+};
+
+static const ASN1_ITEM ESS_CERT_ID_V2_it = {
+	.itype = ASN1_ITYPE_SEQUENCE,
+	.utype = V_ASN1_SEQUENCE,
+	.templates = ESS_CERT_ID_V2_seq_tt,
+	.tcount = sizeof(ESS_CERT_ID_V2_seq_tt) / sizeof(ASN1_TEMPLATE),
+	.funcs = NULL,
+	.size = sizeof(ESS_CERT_ID_V2),
+	.sname = "ESS_CERT_ID_V2",
+};
+
+ESS_CERT_ID_V2 *
+d2i_ESS_CERT_ID_V2(ESS_CERT_ID_V2 **a, const unsigned char **in, long len)
+{
+	return (ESS_CERT_ID_V2 *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
+	    &ESS_CERT_ID_V2_it);
+}
+
+int
+i2d_ESS_CERT_ID_V2(const ESS_CERT_ID_V2 *a, unsigned char **out)
+{
+	return ASN1_item_i2d((ASN1_VALUE *)a, out, &ESS_CERT_ID_V2_it);
+}
+
+ESS_CERT_ID_V2 *
+ESS_CERT_ID_V2_new(void)
+{
+	return (ESS_CERT_ID_V2 *)ASN1_item_new(&ESS_CERT_ID_V2_it);
+}
+
+void
+ESS_CERT_ID_V2_free(ESS_CERT_ID_V2 *a)
+{
+	ASN1_item_free((ASN1_VALUE *)a, &ESS_CERT_ID_V2_it);
+}
+
+ESS_CERT_ID_V2 *
+ESS_CERT_ID_V2_dup(ESS_CERT_ID_V2 *x)
+{
+	return ASN1_item_dup(&ESS_CERT_ID_V2_it, x);
+}
+
+static const ASN1_TEMPLATE ESS_SIGNING_CERT_V2_seq_tt[] = {
+	{
+		.flags = ASN1_TFLG_SEQUENCE_OF,
+		.tag = 0,
+		.offset = offsetof(ESS_SIGNING_CERT_V2, cert_ids),
+		.field_name = "cert_ids",
+		.item = &ESS_CERT_ID_V2_it,
+	},
+	{
+		.flags = ASN1_TFLG_SEQUENCE_OF | ASN1_TFLG_OPTIONAL,
+		.tag = 0,
+		.offset = offsetof(ESS_SIGNING_CERT_V2, policy_info),
+		.field_name = "policy_info",
+		.item = &POLICYINFO_it,
+	},
+};
+
+static const ASN1_ITEM ESS_SIGNING_CERT_V2_it = {
+	.itype = ASN1_ITYPE_SEQUENCE,
+	.utype = V_ASN1_SEQUENCE,
+	.templates = ESS_SIGNING_CERT_V2_seq_tt,
+	.tcount = sizeof(ESS_SIGNING_CERT_V2_seq_tt) / sizeof(ASN1_TEMPLATE),
+	.funcs = NULL,
+	.size = sizeof(ESS_SIGNING_CERT_V2),
+	.sname = "ESS_SIGNING_CERT_V2",
+};
+
+ESS_SIGNING_CERT_V2 *
+d2i_ESS_SIGNING_CERT_V2(ESS_SIGNING_CERT_V2 **a, const unsigned char **in, long len)
+{
+	return (ESS_SIGNING_CERT_V2 *)ASN1_item_d2i((ASN1_VALUE **)a, in, len,
+	    &ESS_SIGNING_CERT_V2_it);
+}
+
+int
+i2d_ESS_SIGNING_CERT_V2(const ESS_SIGNING_CERT_V2 *a, unsigned char **out)
+{
+	return ASN1_item_i2d((ASN1_VALUE *)a, out, &ESS_SIGNING_CERT_V2_it);
+}
+
+ESS_SIGNING_CERT_V2 *
+ESS_SIGNING_CERT_V2_new(void)
+{
+	return (ESS_SIGNING_CERT_V2 *)ASN1_item_new(&ESS_SIGNING_CERT_V2_it);
+}
+
+void
+ESS_SIGNING_CERT_V2_free(ESS_SIGNING_CERT_V2 *a)
+{
+	ASN1_item_free((ASN1_VALUE *)a, &ESS_SIGNING_CERT_V2_it);
+}
+
+ESS_SIGNING_CERT_V2 *
+ESS_SIGNING_CERT_V2_dup(ESS_SIGNING_CERT_V2 *x)
+{
+	return ASN1_item_dup(&ESS_SIGNING_CERT_V2_it, x);
+}
 
 /* Getting encapsulated TS_TST_INFO object from PKCS7. */
 TS_TST_INFO *
@@ -888,3 +1074,4 @@ PKCS7_to_TS_TST_INFO(PKCS7 *token)
 	p = tst_info_der->data;
 	return d2i_TS_TST_INFO(NULL, &p, tst_info_der->length);
 }
+LCRYPTO_ALIAS(PKCS7_to_TS_TST_INFO);
