@@ -1,4 +1,4 @@
-/* $OpenBSD: ts_conf.c,v 1.10 2017/01/29 17:49:23 beck Exp $ */
+/* $OpenBSD: ts_conf.c,v 1.16 2025/05/10 05:54:39 tb Exp $ */
 /* Written by Zoltan Glozik (zglozik@stones.com) for the OpenSSL
  * project 2002.
  */
@@ -56,19 +56,16 @@
  *
  */
 
+#include <limits.h>
+#include <stdlib.h>
 #include <string.h>
 
 #include <openssl/opensslconf.h>
 
 #include <openssl/crypto.h>
-#include <openssl/err.h>
 #include <openssl/pem.h>
 #include <openssl/ts.h>
 
-#ifndef OPENSSL_NO_ENGINE
-#include <openssl/engine.h>
-#endif
-
 /* Macro definitions for the configuration file. */
 
 #define	BASE_SECTION			"tsa"
@@ -110,6 +107,7 @@ end:
 	BIO_free(cert);
 	return x;
 }
+LCRYPTO_ALIAS(TS_CONF_load_cert);
 
 STACK_OF(X509) *
 TS_CONF_load_certs(const char *file)
@@ -144,6 +142,7 @@ end:
 	BIO_free(certs);
 	return othercerts;
 }
+LCRYPTO_ALIAS(TS_CONF_load_certs);
 
 EVP_PKEY *
 TS_CONF_load_key(const char *file, const char *pass)
@@ -161,6 +160,7 @@ end:
 	BIO_free(key);
 	return pkey;
 }
+LCRYPTO_ALIAS(TS_CONF_load_key);
 
 /* Function definitions for handling configuration options. */
 
@@ -186,6 +186,7 @@ TS_CONF_get_tsa_section(CONF *conf, const char *section)
 	}
 	return section;
 }
+LCRYPTO_ALIAS(TS_CONF_get_tsa_section);
 
 int
 TS_CONF_set_serial(CONF *conf, const char *section, TS_serial_cb cb,
@@ -205,55 +206,7 @@ TS_CONF_set_serial(CONF *conf, const char *section, TS_serial_cb cb,
 err:
 	return ret;
 }
-
-#ifndef OPENSSL_NO_ENGINE
-
-int
-TS_CONF_set_crypto_device(CONF *conf, const char *section, const char *device)
-{
-	int ret = 0;
-
-	if (!device)
-		device = NCONF_get_string(conf, section, ENV_CRYPTO_DEVICE);
-
-	if (device && !TS_CONF_set_default_engine(device)) {
-		TS_CONF_invalid(section, ENV_CRYPTO_DEVICE);
-		goto err;
-	}
-	ret = 1;
-
-err:
-	return ret;
-}
-
-int
-TS_CONF_set_default_engine(const char *name)
-{
-	ENGINE *e = NULL;
-	int ret = 0;
-
-	/* Leave the default if builtin specified. */
-	if (strcmp(name, "builtin") == 0)
-		return 1;
-
-	if (!(e = ENGINE_by_id(name)))
-		goto err;
-	/* All the operations are going to be carried out by the engine. */
-	if (!ENGINE_set_default(e, ENGINE_METHOD_ALL))
-		goto err;
-	ret = 1;
-
-err:
-	if (!ret) {
-		TSerror(TS_R_COULD_NOT_SET_ENGINE);
-		ERR_asprintf_error_data("engine:%s", name);
-	}
-	if (e)
-		ENGINE_free(e);
-	return ret;
-}
-
-#endif
+LCRYPTO_ALIAS(TS_CONF_set_serial);
 
 int
 TS_CONF_set_signer_cert(CONF *conf, const char *section, const char *cert,
@@ -279,6 +232,7 @@ err:
 	X509_free(cert_obj);
 	return ret;
 }
+LCRYPTO_ALIAS(TS_CONF_set_signer_cert);
 
 int
 TS_CONF_set_certs(CONF *conf, const char *section, const char *certs,
@@ -303,6 +257,7 @@ err:
 	sk_X509_pop_free(certs_obj, X509_free);
 	return ret;
 }
+LCRYPTO_ALIAS(TS_CONF_set_certs);
 
 int
 TS_CONF_set_signer_key(CONF *conf, const char *section, const char *key,
@@ -328,6 +283,7 @@ err:
 	EVP_PKEY_free(key_obj);
 	return ret;
 }
+LCRYPTO_ALIAS(TS_CONF_set_signer_key);
 
 int
 TS_CONF_set_def_policy(CONF *conf, const char *section, const char *policy,
@@ -355,6 +311,7 @@ err:
 	ASN1_OBJECT_free(policy_obj);
 	return ret;
 }
+LCRYPTO_ALIAS(TS_CONF_set_def_policy);
 
 int
 TS_CONF_set_policies(CONF *conf, const char *section, TS_RESP_CTX *ctx)
@@ -388,6 +345,7 @@ err:
 	sk_CONF_VALUE_pop_free(list, X509V3_conf_free);
 	return ret;
 }
+LCRYPTO_ALIAS(TS_CONF_set_policies);
 
 int
 TS_CONF_set_digests(CONF *conf, const char *section, TS_RESP_CTX *ctx)
@@ -427,6 +385,7 @@ err:
 	sk_CONF_VALUE_pop_free(list, X509V3_conf_free);
 	return ret;
 }
+LCRYPTO_ALIAS(TS_CONF_set_digests);
 
 int
 TS_CONF_set_accuracy(CONF *conf, const char *section, TS_RESP_CTX *ctx)
@@ -436,6 +395,7 @@ TS_CONF_set_accuracy(CONF *conf, const char *section, TS_RESP_CTX *ctx)
 	int secs = 0, millis = 0, micros = 0;
 	STACK_OF(CONF_VALUE) *list = NULL;
 	char *accuracy = NCONF_get_string(conf, section, ENV_ACCURACY);
+	const char *errstr;
 
 	if (accuracy && !(list = X509V3_parse_list(accuracy))) {
 		TS_CONF_invalid(section, ENV_ACCURACY);
@@ -444,14 +404,33 @@ TS_CONF_set_accuracy(CONF *conf, const char *section, TS_RESP_CTX *ctx)
 	for (i = 0; i < sk_CONF_VALUE_num(list); ++i) {
 		CONF_VALUE *val = sk_CONF_VALUE_value(list, i);
 		if (strcmp(val->name, ENV_VALUE_SECS) == 0) {
-			if (val->value)
-				secs = atoi(val->value);
+			if (val->value) {
+				secs = strtonum(val->value, 0, INT_MAX,
+				    &errstr);
+				if (errstr != NULL) {
+					TS_CONF_invalid(section,
+					    ENV_VALUE_SECS);
+					goto err;
+				}
+			}
 		} else if (strcmp(val->name, ENV_VALUE_MILLISECS) == 0) {
-			if (val->value)
-				millis = atoi(val->value);
+			if (val->value) {
+				millis = strtonum(val->value, 1, 999, &errstr);
+				if (errstr != NULL) {
+					TS_CONF_invalid(section,
+					    ENV_VALUE_MILLISECS);
+					goto err;
+				}
+			}
 		} else if (strcmp(val->name, ENV_VALUE_MICROSECS) == 0) {
-			if (val->value)
-				micros = atoi(val->value);
+			if (val->value) {
+				micros = strtonum(val->value, 1, 999, &errstr);
+				if (errstr != NULL) {
+					TS_CONF_invalid(section,
+					    ENV_VALUE_MICROSECS);
+					goto err;
+				}
+			}
 		} else {
 			TS_CONF_invalid(section, ENV_ACCURACY);
 			goto err;
@@ -466,6 +445,7 @@ err:
 	sk_CONF_VALUE_pop_free(list, X509V3_conf_free);
 	return ret;
 }
+LCRYPTO_ALIAS(TS_CONF_set_accuracy);
 
 int
 TS_CONF_set_clock_precision_digits(CONF *conf, const char *section,
@@ -478,7 +458,8 @@ TS_CONF_set_clock_precision_digits(CONF *conf, const char *section,
 	if (!NCONF_get_number_e(conf, section, ENV_CLOCK_PRECISION_DIGITS,
 	    &digits))
 		digits = 0;
-	if (digits < 0 || digits > TS_MAX_CLOCK_PRECISION_DIGITS) {
+	/* We only support second precision, so reject everything else */
+	if (digits != 0) {
 		TS_CONF_invalid(section, ENV_CLOCK_PRECISION_DIGITS);
 		goto err;
 	}
@@ -491,6 +472,7 @@ TS_CONF_set_clock_precision_digits(CONF *conf, const char *section,
 err:
 	return ret;
 }
+LCRYPTO_ALIAS(TS_CONF_set_clock_precision_digits);
 
 static int
 TS_CONF_add_flag(CONF *conf, const char *section, const char *field, int flag,
@@ -516,12 +498,14 @@ TS_CONF_set_ordering(CONF *conf, const char *section, TS_RESP_CTX *ctx)
 {
 	return TS_CONF_add_flag(conf, section, ENV_ORDERING, TS_ORDERING, ctx);
 }
+LCRYPTO_ALIAS(TS_CONF_set_ordering);
 
 int
 TS_CONF_set_tsa_name(CONF *conf, const char *section, TS_RESP_CTX *ctx)
 {
 	return TS_CONF_add_flag(conf, section, ENV_TSA_NAME, TS_TSA_NAME, ctx);
 }
+LCRYPTO_ALIAS(TS_CONF_set_tsa_name);
 
 int
 TS_CONF_set_ess_cert_id_chain(CONF *conf, const char *section, TS_RESP_CTX *ctx)
@@ -529,3 +513,4 @@ TS_CONF_set_ess_cert_id_chain(CONF *conf, const char *section, TS_RESP_CTX *ctx)
 	return TS_CONF_add_flag(conf, section, ENV_ESS_CERT_ID_CHAIN,
 	    TS_ESS_CERT_ID_CHAIN, ctx);
 }
+LCRYPTO_ALIAS(TS_CONF_set_ess_cert_id_chain);
