@@ -1,4 +1,4 @@
-/* $OpenBSD: by_dir.c,v 1.46 2023/12/29 05:33:32 tb Exp $ */
+/* $OpenBSD: by_dir.c,v 1.49 2025/05/10 05:54:39 tb Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -56,9 +56,6 @@
  * [including the GNU Public Licence.]
  */
 
-#include <sys/stat.h>
-#include <sys/types.h>
-
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
@@ -67,9 +64,9 @@
 
 #include <openssl/opensslconf.h>
 
-#include <openssl/err.h>
 #include <openssl/x509.h>
 
+#include "err_local.h"
 #include "x509_local.h"
 
 typedef struct lookup_dir_hashes_st {
@@ -99,7 +96,7 @@ static int add_cert_dir(BY_DIR *ctx, const char *dir, int type);
 static int get_cert_by_subject(X509_LOOKUP *xl, int type, X509_NAME *name,
     X509_OBJECT *ret);
 
-static X509_LOOKUP_METHOD x509_dir_lookup = {
+static const X509_LOOKUP_METHOD x509_dir_lookup = {
 	.name = "Load certs from files in a directory",
 	.new_item = new_dir,
 	.free = free_dir,
@@ -107,7 +104,7 @@ static X509_LOOKUP_METHOD x509_dir_lookup = {
 	.get_by_subject = get_cert_by_subject,
 };
 
-X509_LOOKUP_METHOD *
+const X509_LOOKUP_METHOD *
 X509_LOOKUP_hash_dir(void)
 {
 	return &x509_dir_lookup;
@@ -331,23 +328,27 @@ get_cert_by_subject(X509_LOOKUP *xl, int type, X509_NAME *name,
 		for (;;) {
 			(void) snprintf(b->data, b->max, "%s/%08lx.%s%d",
 			    ent->dir, h, postfix, k);
-
-			{
-				struct stat st;
-				if (stat(b->data, &st) < 0)
-					break;
-			}
-			/* found one. */
+			/*
+			 * Found one. Attempt to load it. This could fail for
+			 * any number of reasons from the file can't be opened,
+			 * the file contains garbage, etc. Clear the error stack
+			 * to avoid exposing the lower level error. These all
+			 * boil down to "we could not find CA/CRL".
+			 */
 			if (type == X509_LU_X509) {
 				if ((X509_load_cert_file(xl, b->data,
-				    ent->dir_type)) == 0)
+				    ent->dir_type)) == 0) {
+					ERR_clear_error();
 					break;
+				}
 			} else if (type == X509_LU_CRL) {
 				if ((X509_load_crl_file(xl, b->data,
-				    ent->dir_type)) == 0)
+				    ent->dir_type)) == 0) {
+					ERR_clear_error();
 					break;
+				}
 			}
-			/* else case will caught higher up */
+			/* The lack of a CA or CRL will be caught higher up. */
 			k++;
 		}
 
