@@ -1,4 +1,4 @@
-/*	$OpenBSD: ssl_namespace.h,v 1.3 2024/07/12 05:26:34 miod Exp $	*/
+/*	$OpenBSD: ssl_namespace.h,v 1.4 2025/08/18 16:00:53 tb Exp $	*/
 /*
  * Copyright (c) 2016 Philip Guenther <guenther@openbsd.org>
  *
@@ -23,11 +23,6 @@
  * and we alias that to the normal name.
  */
 
-#ifdef _MSC_VER
-#define LSSL_UNUSED(x)
-#define LSSL_USED(x)
-#define LSSL_ALIAS(x)
-#else
 #ifdef LIBRESSL_NAMESPACE
 #define LSSL_UNUSED(x)		typeof(x) x __attribute__((deprecated))
 #define LSSL_USED(x)		__attribute__((visibility("hidden")))	\
@@ -40,8 +35,11 @@
 #else
 #define LSSL_UNUSED(x)
 #define LSSL_USED(x)
+#ifdef _MSC_VER
+#define LSSL_ALIAS(x)
+#else
 #define LSSL_ALIAS(x)		asm("")
-#endif
 #endif /* _MSC_VER */
+#endif
 
 #endif	/* _LIBSSL_SSL_NAMESPACE_H_ */
