@@ -1,4 +1,4 @@
-/* $OpenBSD: ssl_both.c,v 1.42 2022/02/05 14:54:10 jsing Exp $ */
+/* $OpenBSD: ssl_both.c,v 1.47 2024/02/03 15:58:33 beck Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -124,11 +124,11 @@
 #include <openssl/x509.h>
 
 #include "bytestring.h"
-#include "dtls_locl.h"
-#include "ssl_locl.h"
+#include "dtls_local.h"
+#include "ssl_local.h"
 
 /*
- * Send s->internal->init_buf in records of type 'type' (SSL3_RT_HANDSHAKE or
+ * Send s->init_buf in records of type 'type' (SSL3_RT_HANDSHAKE or
  * SSL3_RT_CHANGE_CIPHER_SPEC).
  */
 int
@@ -136,8 +136,8 @@ ssl3_do_write(SSL *s, int type)
 {
 	int ret;
 
-	ret = ssl3_write_bytes(s, type, &s->internal->init_buf->data[s->internal->init_off],
-	    s->internal->init_num);
+	ret = ssl3_write_bytes(s, type, &s->init_buf->data[s->init_off],
+	    s->init_num);
 	if (ret < 0)
 		return (-1);
 
@@ -147,166 +147,20 @@ ssl3_do_write(SSL *s, int type)
 		 * we'll ignore the result anyway.
 		 */
 		tls1_transcript_record(s,
-		    (unsigned char *)&s->internal->init_buf->data[s->internal->init_off], ret);
+		    (unsigned char *)&s->init_buf->data[s->init_off], ret);
 
-	if (ret == s->internal->init_num) {
-		ssl_msg_callback(s, 1, type, s->internal->init_buf->data,
-		    (size_t)(s->internal->init_off + s->internal->init_num));
+	if (ret == s->init_num) {
+		ssl_msg_callback(s, 1, type, s->init_buf->data,
+		    (size_t)(s->init_off + s->init_num));
 		return (1);
 	}
 
-	s->internal->init_off += ret;
-	s->internal->init_num -= ret;
+	s->init_off += ret;
+	s->init_num -= ret;
 
 	return (0);
 }
 
-int
-ssl3_send_finished(SSL *s, int state_a, int state_b)
-{
-	CBB cbb, finished;
-
-	memset(&cbb, 0, sizeof(cbb));
-
-	if (s->s3->hs.state == state_a) {
-		if (!tls12_derive_finished(s))
-			goto err;
-
-		/* Copy finished so we can use it for renegotiation checks. */
-		if (!s->server) {
-			memcpy(s->s3->previous_client_finished,
-			    s->s3->hs.finished, s->s3->hs.finished_len);
-			s->s3->previous_client_finished_len =
-			    s->s3->hs.finished_len;
-		} else {
-			memcpy(s->s3->previous_server_finished,
-			    s->s3->hs.finished, s->s3->hs.finished_len);
-			s->s3->previous_server_finished_len =
-			    s->s3->hs.finished_len;
-		}
-
-		if (!ssl3_handshake_msg_start(s, &cbb, &finished,
-		    SSL3_MT_FINISHED))
-                        goto err;
-		if (!CBB_add_bytes(&finished, s->s3->hs.finished,
-		    s->s3->hs.finished_len))
-			goto err;
-		if (!ssl3_handshake_msg_finish(s, &cbb))
-			goto err;
-
-		s->s3->hs.state = state_b;
-	}
-
-	return (ssl3_handshake_write(s));
-
- err:
-	CBB_cleanup(&cbb);
-
-	return (-1);
-}
-
-int
-ssl3_get_finished(SSL *s, int a, int b)
-{
-	int al, md_len, ret;
-	CBS cbs;
-
-	/* should actually be 36+4 :-) */
-	if ((ret = ssl3_get_message(s, a, b, SSL3_MT_FINISHED, 64)) <= 0)
-		return ret;
-
-	/* If this occurs, we have missed a message */
-	if (!s->s3->change_cipher_spec) {
-		al = SSL_AD_UNEXPECTED_MESSAGE;
-		SSLerror(s, SSL_R_GOT_A_FIN_BEFORE_A_CCS);
-		goto fatal_err;
-	}
-	s->s3->change_cipher_spec = 0;
-
-	md_len = TLS1_FINISH_MAC_LENGTH;
-
-	if (s->internal->init_num < 0) {
-		al = SSL_AD_DECODE_ERROR;
-		SSLerror(s, SSL_R_BAD_DIGEST_LENGTH);
-		goto fatal_err;
-	}
-
-	CBS_init(&cbs, s->internal->init_msg, s->internal->init_num);
-
-	if (s->s3->hs.peer_finished_len != md_len ||
-	    CBS_len(&cbs) != md_len) {
-		al = SSL_AD_DECODE_ERROR;
-		SSLerror(s, SSL_R_BAD_DIGEST_LENGTH);
-		goto fatal_err;
-	}
-
-	if (!CBS_mem_equal(&cbs, s->s3->hs.peer_finished, CBS_len(&cbs))) {
-		al = SSL_AD_DECRYPT_ERROR;
-		SSLerror(s, SSL_R_DIGEST_CHECK_FAILED);
-		goto fatal_err;
-	}
-
-	/* Copy finished so we can use it for renegotiation checks. */
-	OPENSSL_assert(md_len <= EVP_MAX_MD_SIZE);
-	if (s->server) {
-		memcpy(s->s3->previous_client_finished,
-		    s->s3->hs.peer_finished, md_len);
-		s->s3->previous_client_finished_len = md_len;
-	} else {
-		memcpy(s->s3->previous_server_finished,
-		    s->s3->hs.peer_finished, md_len);
-		s->s3->previous_server_finished_len = md_len;
-	}
-
-	return (1);
- fatal_err:
-	ssl3_send_alert(s, SSL3_AL_FATAL, al);
-	return (0);
-}
-
-int
-ssl3_send_change_cipher_spec(SSL *s, int a, int b)
-{
-	size_t outlen;
-	CBB cbb;
-
-	memset(&cbb, 0, sizeof(cbb));
-
-	if (s->s3->hs.state == a) {
-		if (!CBB_init_fixed(&cbb, s->internal->init_buf->data,
-		    s->internal->init_buf->length))
-			goto err;
-		if (!CBB_add_u8(&cbb, SSL3_MT_CCS))
-			goto err;
-		if (!CBB_finish(&cbb, NULL, &outlen))
-			goto err;
-
-		if (outlen > INT_MAX)
-			goto err;
-
-		s->internal->init_num = (int)outlen;
-		s->internal->init_off = 0;
-
-		if (SSL_is_dtls(s)) {
-			s->d1->handshake_write_seq =
-			    s->d1->next_handshake_write_seq;
-			dtls1_set_message_header_int(s, SSL3_MT_CCS, 0,
-			    s->d1->handshake_write_seq, 0, 0);
-			dtls1_buffer_message(s, 1);
-		}
-
-		s->s3->hs.state = b;
-	}
-
-	/* SSL3_ST_CW_CHANGE_B */
-	return ssl3_record_write(s, SSL3_RT_CHANGE_CIPHER_SPEC);
-
- err:
-	CBB_cleanup(&cbb);
-
-	return -1;
-}
-
 static int
 ssl3_add_cert(CBB *cbb, X509 *x)
 {
@@ -353,7 +207,7 @@ ssl3_output_cert_chain(SSL *s, CBB *cbb, SSL_CERT_PKEY *cpk)
 	if ((chain = cpk->chain) == NULL)
 		chain = s->ctx->extra_certs;
 
-	if (chain != NULL || (s->internal->mode & SSL_MODE_NO_AUTO_CHAIN)) {
+	if (chain != NULL || (s->mode & SSL_MODE_NO_AUTO_CHAIN)) {
 		if (!ssl3_add_cert(&cert_list, cpk->x509))
 			goto err;
 	} else {
@@ -415,27 +269,27 @@ ssl3_get_message(SSL *s, int st1, int stn, int mt, long max)
 			SSLerror(s, SSL_R_UNEXPECTED_MESSAGE);
 			goto fatal_err;
 		}
-		s->internal->init_msg = s->internal->init_buf->data +
+		s->init_msg = s->init_buf->data +
 		    SSL3_HM_HEADER_LENGTH;
-		s->internal->init_num = (int)s->s3->hs.tls12.message_size;
+		s->init_num = (int)s->s3->hs.tls12.message_size;
 		return 1;
 	}
 
-	p = (unsigned char *)s->internal->init_buf->data;
+	p = (unsigned char *)s->init_buf->data;
 
 	if (s->s3->hs.state == st1) {
 		int skip_message;
 
 		do {
-			while (s->internal->init_num < SSL3_HM_HEADER_LENGTH) {
+			while (s->init_num < SSL3_HM_HEADER_LENGTH) {
 				i = s->method->ssl_read_bytes(s,
-				    SSL3_RT_HANDSHAKE, &p[s->internal->init_num],
-				    SSL3_HM_HEADER_LENGTH - s->internal->init_num, 0);
+				    SSL3_RT_HANDSHAKE, &p[s->init_num],
+				    SSL3_HM_HEADER_LENGTH - s->init_num, 0);
 				if (i <= 0) {
-					s->internal->rwstate = SSL_READING;
+					s->rwstate = SSL_READING;
 					return i;
 				}
-				s->internal->init_num += i;
+				s->init_num += i;
 			}
 
 			skip_message = 0;
@@ -447,7 +301,7 @@ ssl3_get_message(SSL *s, int st1, int stn, int mt, long max)
 				 * correct.  Does not count for 'Finished' MAC.
 				 */
 				if (p[1] == 0 && p[2] == 0 &&p[3] == 0) {
-					s->internal->init_num = 0;
+					s->init_num = 0;
 					skip_message = 1;
 
 					ssl_msg_callback(s, 0,
@@ -476,7 +330,7 @@ ssl3_get_message(SSL *s, int st1, int stn, int mt, long max)
 			SSLerror(s, SSL_R_EXCESSIVE_MESSAGE_SIZE);
 			goto fatal_err;
 		}
-		if (l && !BUF_MEM_grow_clean(s->internal->init_buf,
+		if (l && !BUF_MEM_grow_clean(s->init_buf,
 		    l + SSL3_HM_HEADER_LENGTH)) {
 			SSLerror(s, ERR_R_BUF_LIB);
 			goto err;
@@ -484,33 +338,33 @@ ssl3_get_message(SSL *s, int st1, int stn, int mt, long max)
 		s->s3->hs.tls12.message_size = l;
 		s->s3->hs.state = stn;
 
-		s->internal->init_msg = s->internal->init_buf->data +
+		s->init_msg = s->init_buf->data +
 		    SSL3_HM_HEADER_LENGTH;
-		s->internal->init_num = 0;
+		s->init_num = 0;
 	}
 
 	/* next state (stn) */
-	p = s->internal->init_msg;
-	n = s->s3->hs.tls12.message_size - s->internal->init_num;
+	p = s->init_msg;
+	n = s->s3->hs.tls12.message_size - s->init_num;
 	while (n > 0) {
 		i = s->method->ssl_read_bytes(s, SSL3_RT_HANDSHAKE,
-		    &p[s->internal->init_num], n, 0);
+		    &p[s->init_num], n, 0);
 		if (i <= 0) {
-			s->internal->rwstate = SSL_READING;
+			s->rwstate = SSL_READING;
 			return i;
 		}
-		s->internal->init_num += i;
+		s->init_num += i;
 		n -= i;
 	}
 
 	/* Feed this message into MAC computation. */
-	if (s->internal->mac_packet) {
-		tls1_transcript_record(s, (unsigned char *)s->internal->init_buf->data,
-		    s->internal->init_num + SSL3_HM_HEADER_LENGTH);
+	if (s->mac_packet) {
+		tls1_transcript_record(s, (unsigned char *)s->init_buf->data,
+		    s->init_num + SSL3_HM_HEADER_LENGTH);
 
 		ssl_msg_callback(s, 0, SSL3_RT_HANDSHAKE,
-		    s->internal->init_buf->data,
-		    (size_t)s->internal->init_num + SSL3_HM_HEADER_LENGTH);
+		    s->init_buf->data,
+		    (size_t)s->init_num + SSL3_HM_HEADER_LENGTH);
 	}
 
 	return 1;
@@ -530,10 +384,8 @@ ssl_cert_type(EVP_PKEY *pkey)
 	switch (EVP_PKEY_id(pkey)) {
 	case EVP_PKEY_EC:
 		return SSL_PKEY_ECC;
-	case NID_id_GostR3410_2001:
-	case NID_id_GostR3410_2001_cc:
-		return SSL_PKEY_GOST01;
 	case EVP_PKEY_RSA:
+	case EVP_PKEY_RSA_PSS:
 		return SSL_PKEY_RSA;
 	}
 
@@ -605,7 +457,7 @@ ssl3_setup_init_buffer(SSL *s)
 {
 	BUF_MEM *buf = NULL;
 
-	if (s->internal->init_buf != NULL)
+	if (s->init_buf != NULL)
 		return (1);
 
 	if ((buf = BUF_MEM_new()) == NULL)
@@ -613,7 +465,7 @@ ssl3_setup_init_buffer(SSL *s)
 	if (!BUF_MEM_grow(buf, SSL3_RT_MAX_PLAIN_LENGTH))
 		goto err;
 
-	s->internal->init_buf = buf;
+	s->init_buf = buf;
 	return (1);
 
  err:
@@ -624,11 +476,11 @@ ssl3_setup_init_buffer(SSL *s)
 void
 ssl3_release_init_buffer(SSL *s)
 {
-	BUF_MEM_free(s->internal->init_buf);
-	s->internal->init_buf = NULL;
-	s->internal->init_msg = NULL;
-	s->internal->init_num = 0;
-	s->internal->init_off = 0;
+	BUF_MEM_free(s->init_buf);
+	s->init_buf = NULL;
+	s->init_msg = NULL;
+	s->init_num = 0;
+	s->init_off = 0;
 }
 
 int
@@ -653,7 +505,7 @@ ssl3_setup_read_buffer(SSL *s)
 		s->s3->rbuf.len = len;
 	}
 
-	s->internal->packet = s->s3->rbuf.buf;
+	s->packet = s->s3->rbuf.buf;
 	return 1;
 
  err:
@@ -677,7 +529,7 @@ ssl3_setup_write_buffer(SSL *s)
 	if (s->s3->wbuf.buf == NULL) {
 		len = s->max_send_fragment +
 		    SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD + headerlen + align;
-		if (!(s->internal->options & SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS))
+		if (!(s->options & SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS))
 			len += headerlen + align +
 			    SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD;
 
